/* message.c:

     Provides informational output at various levels of verbosity.
     Debug and normal levels go to stdout, errors to stderr, and fatal
     errors cause exit with status 1.
*/

#include <stdio.h>
#include <stdarg.h>

#define MESSAGE_C		/* to declare logLevel our own */
#include "message.h"

void message(int level, char * format, ...) {
    va_list args;
    FILE * where = stderr;

    if (level >= logLevel) {
	va_start(args, format);

	switch (level) {
	    case LOG_REALDEBUG:
	    case LOG_DEBUG:
		where = stdout;
		break;

	    case LOG_NORMAL:
	    case LOG_VERBOSE:
		where = stdout;
		break;

	    default:
		fprintf(stderr, "error: ");
	}

	vfprintf(where, format, args);

	if (level == LOG_FATAL) exit(1);
    }
}

